@@ -61,6 +61,13 @@ maplist = {
            }
 
 
+def to_str(s):
+    """非字符串转换为字符串"""
+    if isinstance(s, text_type) or isinstance(s, binary_type):
+        return s
+    return str(s)
+
+
 def to_unicode(s):
     """将字符串转为unicode"""
     if isinstance(s, binary_type):
@@ -405,3 +412,11 @@ def get_date(yy, mm, dd):
     date_str = datetime(yy, mm, dd).isoformat()
     final_date_str = date_str+'+08:00'
     return final_date_str
+
+
+class CiDetectType():
+    """ci内容设备的类型设置,可与操作设多个"""
+    PORN = 1
+    TERRORIST = 2
+    POLITICS = 4
+    ADS = 8
